@@ -645,7 +645,7 @@ class BaseCfgLine(object):
         ## iterate through children, and return the matching value 
         ##  (cast as result_type) from the first child.text that matches regex
 
-        if isinstance(default, bool) and (default is True):
+        if (default is True):
             ## Not using self.re_match_iter_typed(default=True), because I want
             ##   to be sure I build the correct API for match=False
             ##
